<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class Countries extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()

    {


    Schema::create('countries', function (Blueprint $table) {
            $table->increments('id');
            $table->string('con_name', 100);
            $table->enum('con_status', ['0', '1']);
            $table->timestamps();
        });
      Schema::create('states', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('con_id')->unsigned();
            $table->foreign('con_id')->references('id')->on('countries')->onDelete('cascade');
            $table->string('st_name', 100);
            $table->enum('st_status', ['0', '1']);
            $table->timestamps();
        });
      Schema::create('cities', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('st_id')->unsigned();
            $table->foreign('st_id')->references('id')->on('states')->onDelete('cascade');
            $table->string('ct_name', 100);
            $table->enum('ct_status', ['0', '1']);
            $table->timestamps();
        });
      Schema::create('locations', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('con_id')->unsigned();
            $table->integer('st_id')->unsigned();
            $table->integer('ct_id')->unsigned();
            $table->foreign('con_id')->references('id')->on('countries');
            $table->foreign('st_id')->references('id')->on('states');
            $table->foreign('ct_id')->references('id')->on('cities');
            $table->string('loc_name', 100);
            $table->enum('loc_status', ['0', '1']);
            $table->timestamps();
        });
        Schema::create('contracts', function (Blueprint $table) {
            $table->increments('id');
            $table->string('cont_name', 100);
            $table->enum('cont_status', ['0', '1']);
            $table->timestamps();
        });
      Schema::create('customers', function (Blueprint $table) {
            $table->increments('id');
            $table->string('c_name', 100);
            $table->string('cmpy_name', 100);
            $table->text('c_address');
            $table->string('c_email', 100);
            $table->string('c_phn', 100);
            $table->integer('loc_id')->unsigned();
            $table->foreign('loc_id')->references('id')->on('locations');
            $table->string('c_pwd', 100);
            $table->integer('c_con_type')->unsigned();
            $table->foreign('c_con_type')->references('id')->on('contracts')->onDelete('cascade');
            $table->dateTime('c_start_date');
            $table->dateTime('c_end_date');
            $table->string('c_role', 100);
            $table->enum('c_status', ['0', '1']);
            $table->timestamps();
        });
      Schema::create('categories', function (Blueprint $table) {
            $table->increments('id');
            $table->string('cat_name', 100);
            $table->enum('cat_status', ['0', '1']);
            $table->timestamps();
        });
 Schema::create('serials', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('cat_id')->unsigned();
            $table->foreign('cat_id')->references('id')->on('categories')->onDelete('cascade');
            $table->string('serial_no', 100);
            //$table->string('sla', 100);
            //$table->dateTime('c_start_date');
            //$table->dateTime('c_end_date');          
            $table->timestamps();
        });

       Schema::create('oems', function (Blueprint $table) {
            $table->increments('id');
            $table->string('oem_name', 100);
            $table->integer('cat_id')->unsigned();
            $table->foreign('cat_id')->references('id')->on('categories')->onDelete('cascade');
            $table->integer('serial_id')->unsigned();
            $table->foreign('serial_id')->references('id')->on('serials')->onDelete('cascade');
            $table->enum('oem_status', ['0', '1']);
            $table->timestamps();
        });
      Schema::create('oemmodels', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('oem_id')->unsigned();
            $table->foreign('oem_id')->references('id')->on('oems')->onDelete('cascade');
            $table->integer('cat_id')->unsigned();
            $table->foreign('cat_id')->references('id')->on('categories')->onDelete('cascade');
            $table->integer('serial_id')->unsigned();
            $table->foreign('serial_id')->references('id')->on('serials')->onDelete('cascade');
            $table->string('mod_name', 100);
            $table->enum('mod_status', ['0', '1']);
            $table->timestamps();
        });
      Schema::create('masters', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('oem_id')->unsigned();
            $table->integer('mod_id')->unsigned();
            $table->integer('loc_id')->unsigned();
            $table->integer('cat_id')->unsigned();
            $table->integer('serial_id')->unsigned();
            $table->foreign('cat_id')->references('id')->on('categories')->onDelete('cascade');
            $table->foreign('serial_id')->references('id')->on('serials')->onDelete('cascade');
            $table->foreign('oem_id')->references('id')->on('oems')->onDelete('cascade');
            $table->foreign('mod_id')->references('id')->on('oemmodels')->onDelete('cascade');
            $table->foreign('loc_id')->references('id')->on('locations')->onDelete('cascade');
            $table->string('prt_no', 100);
            $table->text('prt_desc');
            $table->integer('prt_qty');
            $table->string('sn', 100);
            $table->string('serial_no', 100);
            $table->string('track', 100);
            $table->string('location_of_tray', 100);
            
            $table->enum('mas_status', ['0', '1']);
            $table->timestamps();
        });
    Schema::create('assets', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('c_id')->unsigned();
            $table->integer('mas_id')->unsigned();
            $table->foreign('c_id')->references('id')->on('customers')->onDelete('cascade');
            $table->foreign('mas_id')->references('id')->on('masters')->onDelete('cascade');
            $table->integer('qty');
            $table->timestamps();
        });
     Schema::create('parts', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('c_id')->unsigned();
            $table->integer('cat_id')->unsigned();
            $table->integer('ser_id')->unsigned();
            $table->foreign('c_id')->references('id')->on('customers')->onDelete('cascade');
            $table->foreign('cat_id')->references('id')->on('categories')->onDelete('cascade');
             $table->foreign('ser_id')->references('id')->on('serials')->onDelete('cascade');           
            $table->timestamps();
        });
    Schema::create('teches', function (Blueprint $table) {
            $table->increments('id');
            $table->string('tc_name', 100);
            $table->string('tc_email', 100);
            $table->string('tc_phn', 100);
            $table->integer('loc_id')->unsigned();
            $table->foreign('loc_id')->references('id')->on('locations')->onDelete('cascade');
            $table->string('tc_pwd', 100);
            $table->string('tc_skill', 100);
            $table->dateTime('tc_join_date');
            $table->enum('tc_status', ['0', '1']);
            $table->timestamps();
        });
    Schema::create('logins', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('user_id')->unsigned();
            $table->foreign('user_id')->references('id')->on('customers'))->onDelete('cascade');
            $table->string('email', 100);
            $table->string('pwd', 100);
            $table->string('role', 100);
            $table->enum('log_status', ['0', '1']);
            $table->timestamps();
        });
    Schema::create('tickets', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('c_id')->unsigned();
            $table->integer('loc_id')->unsigned();
            $table->integer('ast_id')->unsigned();
            $table->foreign('c_id')->references('id')->on('customers')->onDelete('cascade');
            $table->foreign('loc_id')->references('id')->on('locations')->onDelete('cascade');
            $table->foreign('ast_id')->references('id')->on('assets')->onDelete('cascade');
            $table->string('tic_subject', 100);
            $table->text('tic_desc');
            $table->string('tic_sr_no', 100);
            $table->string('tic_otherpart', 100);
            $table->string('tic_email', 100);
            $table->string('tic_phn', 100);
            $table->string('tic_source', 100);
            $table->string('tic_type', 100);
            $table->enum('tic_status', ['0', '1']);
            $table->timestamps();
        });
    Schema::create('attachments', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('tic_id')->unsigned();
            $table->foreign('tic_id')->references('id')->on('tickets')->onDelete('cascade');
            $table->string('att_name', 100);
            $table->timestamps();
        });
    Schema::create('replies', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('tic_id')->unsigned();
            $table->integer('att_id')->unsigned();
            $table->foreign('tic_id')->references('id')->on('tickets')->onDelete('cascade');
            $table->foreign('att_id')->references('id')->on('attachments')->onDelete('cascade');
            $table->text('rly_text');
            $table->timestamps();
        });
    Schema::create('statuses', function (Blueprint $table) {
            $table->increments('id');
            $table->string('sta_name', 100);
            $table->enum('sta_status', ['0', '1']);
            $table->timestamps();
        });
    Schema::create('roles', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('sta_id')->unsigned();
            $table->foreign('sta_id')->references('id')->on('statuses')->onDelete('cascade');
            $table->string('role', 100);
            $table->timestamps();
        });
    Schema::create('assistances', function (Blueprint $table) {
            $table->increments('id');
            $table->string('skills', 100);
            $table->integer('no_fe');
            $table->integer('c_id')->unsigned();            
            $table->foreign('c_id')->references('id')->on('customers');
            $table->dateTime('time');
            $table->dateTime('date');
            $table->integer('loc_id')->unsigned();
            $table->foreign('loc_id')->references('id')->on('locations')->onDelete('cascade');
            $table->timestamps();
        });
    Schema::create('purchases', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('qty');
            $table->integer('tic_id')->unsigned();
            $table->foreign('tic_id')->references('id')->on('tickets')->onDelete('cascade');
            $table->string('prt_no', 100);
            $table->string('prt_desc', 100);
            $table->timestamps();
        });
    Schema::create('reports', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('tic_id')->unsigned();
            $table->integer('sta_id')->unsigned();
            $table->foreign('tic_id')->references('id')->on('tickets')->onDelete('cascade');
            $table->foreign('sta_id')->references('id')->on('statuses')->onDelete('cascade');
            $table->dateTime('tdate');
            $table->dateTime('start_time');
            $table->dateTime('end_time');
            $table->dateTime('travel_time');
            $table->dateTime('arr_site_time');
            $table->dateTime('dep_site_time');            
            $table->integer('pto_id');
            $table->enum('multiple_visit', ['0', '1']);
            $table->enum('slr_meets', ['0', '1']);
            $table->string('fe_upload', 100);
            $table->text('work_done');
            $table->integer('mission_status');
            $table->integer('customer_satisfied');
            $table->timestamps();
        });
    Schema::create('defectives', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('tic_id')->unsigned();
            $table->foreign('tic_id')->references('id')->on('tickets')->onDelete('cascade');
            $table->string('ref', 100);
            $table->integer('rep_id')->unsigned();
            $table->foreign('rep_id')->references('id')->on('reports')->onDelete('cascade');
            $table->string('prt_no', 100);
            $table->string('serial_no', 100);
            $table->string('tag_id', 100);
            $table->timestamps();
        });
    Schema::create('replacements', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('tic_id')->unsigned();
            $table->foreign('tic_id')->references('id')->on('tickets')->onDelete('cascade');
            $table->string('ref', 100);
            $table->integer('rep_id')->unsigned();
            $table->foreign('rep_id')->references('id')->on('reports')->onDelete('cascade');
            $table->integer('ast_id')->unsigned();
            $table->foreign('ast_id')->references('id')->on('assets');
            $table->string('prt_no', 100);
            $table->string('serial_no', 100);
            $table->string('tag_id', 100);
            $table->timestamps();
        });
    Schema::create('logs', function (Blueprint $table) {
            $table->increments('id');
            $table->text('log_desc');
            $table->integer('tic_id')->unsigned();
            $table->foreign('tic_id')->references('id')->on('tickets')->onDelete('cascade');
            $table->timestamps();
        });
    Schema::create('transactions', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('tc_id')->unsigned();
            $table->integer('tic_id')->unsigned();
            $table->foreign('tc_id')->references('id')->on('techs')->onDelete('cascade');
            $table->foreign('tic_id')->references('id')->on('tickets')->onDelete('cascade');
            $table->text('description');
            $table->timestamps();
        });



    }


    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('countries');
        Schema::dropIfExists('states');
        Schema::dropIfExists('cities');
        Schema::dropIfExists('locations');
        Schema::dropIfExists('customers');
        Schema::dropIfExists('oem');
        Schema::dropIfExists('oemmodels');
        Schema::dropIfExists('masters');
        Schema::dropIfExists('assets');
        Schema::dropIfExists('techs');
        Schema::dropIfExists('logins');
        Schema::dropIfExists('tickets');
        Schema::dropIfExists('attachments');
        Schema::dropIfExists('replies');
        Schema::dropIfExists('statuses');
        Schema::dropIfExists('roles');
        Schema::dropIfExists('assistances');
        Schema::dropIfExists('purchases');
        Schema::dropIfExists('reports');
        Schema::dropIfExists('logs');
        Schema::dropIfExists('transactions');
        Schema::dropIfExists('contracts');
    }
}
